@@ -81,9 +81,14 @@ class asynctask(object):
 
     def exec_f(self, f, fname, args, kwargs):
         """Execute the method f asynchronously, in a mocked flask context"""
-        url = args[1] if len(args) > 1 else 'https://127.0.0.1/local'
-        token = args[2] if len(args) > 2 else None
-        args = args[3:] if len(args) > 3 else []
+
+        if len(args) > 0 and args[0] == self.magic:
+            url = args[1]
+            token = args[2]
+            args = args[3:]
+        else:
+            url = 'https://127.0.0.1/local'
+            token = None
 
         log.info('')
         log.info('')
@@ -147,14 +152,11 @@ class asynctask(object):
 
             # Is this code called with the magic word as first param?
             # Or is this code called from a standalone script outside of a server request?
-            log.info(f"has_request_context: {has_request_context()}")
-            log.debug(f"fname: {fname}")
-            log.debug(f"args: {args}")
-            log.debug(f"kwargs: {kwargs}")
             if arg0 == self.magic or not has_request_context():
                 # Weee!! We are running asynchronous. Let's mock the flask
                 # context and execute the sync method
 
+                log.info(f'Calling async task directly: {fname}')
                 self.exec_f(f, fname, args, kwargs)
 
             else:
